export declare type HeaderType = {
    [key: string]: string;
};
declare type SingleEndpointType = {
    [key: string]: string | {
        [key: string]: string | SingleEndpointType;
    };
};
export declare type EndpointsType = {
    [key: string]: SingleEndpointType;
} | {};
declare type ParamBodyType = string | boolean | number | undefined | null;
export declare type RequestBodyType = {
    [key: string]: ParamBodyType | RequestBodyType;
};
export declare type ResolveUrlConfigType = {
    /** Object key=>value, each key will be replaced in the url for the corresponding value, use :key: to wrap your desired keys */
    replace?: {
        [key: string]: number | string;
    } | {} | undefined | null;
};
export declare type RequestConfigType = {
    /** Provide content for the authorization header */
    auth?: string;
    /** Url for the api server */
    debug?: boolean;
    /** Method to be used in the request */
    method?: 'get' | 'post' | 'patch' | 'put' | 'delete';
    /** params that will be send in the request url (only when get) */
    params?: {
        [key: string]: string;
    };
    /** Payload to be used in the request body (only post, patch, put) */
    data?: RequestBodyType;
};
export declare type HttpClientType = {
    /** Provide a content for the Authorization header */
    auth?: string | undefined | null;
    /** Url for the api server */
    server: string | undefined;
    /** If you want to debug the requests, if true every response will contain request info, send headers and payload */
    debug?: boolean;
    /** If you want to log every request made */
    log?: boolean;
    /** Object with the application endpoints */
    endpoints?: EndpointsType;
    /** Function that will be called after every request is done */
    onRequestDone?: ((r?: any) => void) | undefined;
};
export declare type ResponseObjectType = {
    [key: string]: string | boolean | number | null | any | ResponseObjectType;
};
export declare type ResponseType = {
    [key: string]: ResponseObjectType;
} | [{
    [key: string]: ResponseObjectType;
}] | null | any;
export {};
